#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.notification_properties"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[1925]; const double alignment; void * const ptr;}  notification_properties_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0310, 0000, 0000, 0000, 0000, 0000, 0000, 0050, 0006, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 
  0004, 0000, 0000, 0000, 0005, 0000, 0000, 0000, 0212, 0044, 0233, 0353, 0005, 0000, 0000, 0000, 
  0310, 0000, 0000, 0000, 0016, 0000, 0114, 0000, 0330, 0000, 0000, 0000, 0334, 0000, 0000, 0000, 
  0113, 0120, 0220, 0013, 0002, 0000, 0000, 0000, 0334, 0000, 0000, 0000, 0004, 0000, 0114, 0000, 
  0340, 0000, 0000, 0000, 0344, 0000, 0000, 0000, 0324, 0265, 0002, 0000, 0377, 0377, 0377, 0377, 
  0344, 0000, 0000, 0000, 0001, 0000, 0114, 0000, 0350, 0000, 0000, 0000, 0354, 0000, 0000, 0000, 
  0247, 0134, 0140, 0271, 0004, 0000, 0000, 0000, 0354, 0000, 0000, 0000, 0037, 0000, 0166, 0000, 
  0020, 0001, 0000, 0000, 0146, 0007, 0000, 0000, 0006, 0204, 0047, 0246, 0000, 0000, 0000, 0000, 
  0146, 0007, 0000, 0000, 0013, 0000, 0114, 0000, 0164, 0007, 0000, 0000, 0170, 0007, 0000, 0000, 
  0201, 0321, 0040, 0031, 0001, 0000, 0000, 0000, 0170, 0007, 0000, 0000, 0005, 0000, 0114, 0000, 
  0200, 0007, 0000, 0000, 0204, 0007, 0000, 0000, 0156, 0157, 0164, 0151, 0146, 0151, 0143, 0141, 
  0164, 0151, 0157, 0156, 0163, 0057, 0000, 0000, 0004, 0000, 0000, 0000, 0157, 0162, 0147, 0057, 
  0005, 0000, 0000, 0000, 0057, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0155, 0141, 0164, 0145, 
  0055, 0156, 0157, 0164, 0151, 0146, 0151, 0143, 0141, 0164, 0151, 0157, 0156, 0055, 0160, 0162, 
  0157, 0160, 0145, 0162, 0164, 0151, 0145, 0163, 0056, 0165, 0151, 0000, 0000, 0000, 0000, 0000, 
  0276, 0075, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0355, 0133, 0133, 0163, 0342, 0066, 
  0024, 0176, 0337, 0137, 0241, 0352, 0141, 0137, 0072, 0136, 0102, 0056, 0335, 0164, 0027, 0330, 
  0111, 0066, 0331, 0154, 0046, 0327, 0111, 0110, 0137, 0065, 0302, 0126, 0100, 0215, 0260, 0134, 
  0131, 0334, 0072, 0375, 0361, 0225, 0154, 0060, 0006, 0344, 0053, 0156, 0002, 0015, 0057, 0214, 
  0261, 0164, 0216, 0164, 0276, 0163, 0323, 0221, 0344, 0306, 0267, 0161, 0237, 0201, 0041, 0021, 
  0076, 0345, 0156, 0023, 0326, 0077, 0355, 0101, 0100, 0134, 0233, 0073, 0324, 0355, 0066, 0341, 
  0123, 0373, 0207, 0165, 0014, 0277, 0265, 0076, 0064, 0250, 0053, 0211, 0170, 0306, 0066, 0151, 
  0175, 0000, 0240, 0041, 0310, 0137, 0003, 0052, 0210, 0017, 0030, 0355, 0064, 0141, 0127, 0276, 
  0374, 0012, 0347, 0074, 0366, 0077, 0325, 0217, 0141, 0055, 0350, 0367, 0213, 0145, 0201, 0210, 
  0322, 0162, 0161, 0137, 0161, 0265, 0074, 0316, 0250, 0075, 0001, 0222, 0173, 0214, 0014, 0011, 
  0263, 0154, 0256, 0172, 0214, 0345, 0000, 0063, 0140, 0131, 0001, 0031, 0357, 0374, 0111, 0154, 
  0011, 0154, 0206, 0175, 0277, 0011, 0057, 0344, 0313, 0031, 0305, 0214, 0167, 0041, 0240, 0116, 
  0023, 0072, 0341, 0263, 0356, 0250, 0272, 0172, 0202, 0173, 0104, 0310, 0011, 0120, 0314, 0111, 
  0023, 0332, 0330, 0105, 0317, 0334, 0036, 0370, 0260, 0365, 0003, 0063, 0237, 0064, 0152, 0263, 
  0016, 0346, 0376, 0152, 0002, 0256, 0124, 0235, 0057, 0316, 0256, 0320, 0375, 0335, 0345, 0155, 
  0373, 0374, 0001, 0335, 0334, 0265, 0057, 0357, 0156, 0321, 0315, 0311, 0343, 0025, 0370, 0007, 
  0030, 0132, 0176, 0252, 0177, 0361, 0346, 0323, 0247, 0166, 0133, 0275, 0276, 0177, 0070, 0177, 
  0174, 0064, 0274, 0177, 0070, 0277, 0076, 0077, 0171, 0074, 0017, 0132, 0262, 0346, 0323, 0341, 
  0302, 0041, 0002, 0215, 0250, 0043, 0173, 0260, 0165, 0224, 0325, 0135, 0122, 0311, 0010, 0004, 
  0122, 0140, 0327, 0147, 0130, 0342, 0016, 0123, 0057, 0047, 0104, 0011, 0164, 0313, 0045, 0175, 
  0246, 0066, 0226, 0112, 0045, 0340, 0221, 0110, 0251, 0220, 0367, 0263, 0330, 0051, 0215, 0322, 
  0277, 0065, 0223, 0234, 0350, 0215, 0250, 0353, 0360, 0021, 0362, 0270, 0117, 0365, 0070, 0260, 
  0145, 0023, 0255, 0154, 0213, 0273, 0226, 0207, 0205, 0172, 0316, 0142, 0100, 0225, 0356, 0221, 
  0176, 0204, 0255, 0076, 0226, 0312, 0102, 0142, 0263, 0266, 0246, 0175, 0051, 0311, 0234, 0267, 
  0234, 0170, 0004, 0365, 0224, 0241, 0301, 0126, 0150, 0035, 0053, 0004, 0166, 0217, 0062, 0047, 
  0064, 0105, 0027, 0053, 0223, 0323, 0177, 0233, 0160, 0330, 0341, 0343, 0251, 0041, 0231, 0254, 
  0356, 0217, 0123, 0325, 0034, 0263, 0071, 0113, 0367, 0257, 0107, 0004, 0253, 0363, 0030, 0122, 
  0237, 0006, 0350, 0265, 0305, 0140, 0005, 0274, 0062, 0346, 0152, 0242, 0361, 0075, 0154, 0053, 
  0145, 0302, 0326, 0276, 0261, 0267, 0131, 0122, 0154, 0153, 0110, 0221, 0122, 0012, 0216, 0315, 
  0337, 0044, 0364, 0317, 0323, 0201, 0224, 0334, 0135, 0026, 0075, 0306, 0240, 0276, 0300, 0241, 
  0004, 0012, 0145, 0221, 0060, 0321, 0061, 0074, 0341, 0003, 0211, 0174, 0071, 0321, 0043, 0022, 
  0327, 0111, 0044, 0014, 0220, 0130, 0174, 0147, 0222, 0077, 0024, 0077, 0224, 0275, 0023, 0074, 
  0037, 0302, 0145, 0252, 0222, 0062, 0147, 0310, 0135, 0224, 0124, 0020, 0233, 0320, 0041, 0361, 
  0221, 0103, 0236, 0361, 0200, 0311, 0014, 0344, 0114, 0054, 0006, 0076, 0101, 0063, 0315, 0172, 
  0036, 0301, 0052, 0216, 0330, 0044, 0017, 0037, 0043, 0230, 0146, 0100, 0117, 0030, 0355, 0272, 
  0175, 0025, 0014, 0102, 0114, 0361, 0354, 0357, 0076, 0064, 0321, 0257, 0001, 0355, 0072, 0146, 
  0225, 0104, 0077, 0366, 0155, 0254, 0307, 0336, 0053, 0112, 0070, 0311, 0115, 0230, 0010, 0145, 
  0222, 0177, 0316, 0074, 0263, 0247, 0242, 0321, 0001, 0114, 0242, 0134, 0023, 0310, 0052, 0300, 
  0054, 0036, 0275, 0212, 0201, 0143, 0006, 0350, 0262, 0217, 0273, 0044, 0104, 0210, 0352, 0307, 
  0175, 0230, 0106, 0137, 0001, 0114, 0125, 0101, 0125, 0141, 0202, 0054, 0302, 0336, 0122, 0071, 
  0137, 0261, 0077, 0310, 0307, 0243, 0121, 0013, 0001, 0117, 0355, 0243, 0164, 0374, 0242, 0224, 
  0134, 0154, 0056, 0144, 0354, 0141, 0327, 0131, 0023, 0257, 0147, 0312, 0330, 0232, 0054, 0346, 
  0253, 0231, 0275, 0274, 0220, 0144, 0312, 0333, 0250, 0145, 0030, 0162, 0031, 0103, 0277, 0306, 
  0035, 0302, 0102, 0103, 0147, 0372, 0261, 0276, 0325, 0226, 0316, 0102, 0151, 0014, 0113, 0131, 
  0164, 0057, 0310, 0220, 0222, 0121, 0131, 0316, 0072, 0311, 0015, 0134, 0265, 0254, 0146, 0324, 
  0055, 0044, 0354, 0173, 0262, 0365, 0372, 0153, 0331, 0172, 0072, 0250, 0051, 0304, 0311, 0204, 
  0011, 0104, 0111, 0004, 0311, 0052, 0053, 0255, 0246, 0222, 0252, 0051, 0025, 0172, 0022, 0124, 
  0140, 0004, 0241, 0374, 0242, 0367, 0050, 0307, 0242, 0067, 0164, 0331, 0226, 0052, 0377, 0055, 
  0233, 0361, 0142, 0242, 0276, 0305, 0202, 0131, 0223, 0106, 0153, 0345, 0155, 0132, 0155, 0033, 
  0370, 0370, 0222, 0333, 0057, 0131, 0122, 0154, 0263, 0007, 0324, 0253, 0360, 0000, 0023, 0000, 
  0146, 0341, 0113, 0011, 0156, 0026, 0272, 0110, 0331, 0253, 0347, 0202, 0364, 0366, 0105, 0172, 
  0355, 0132, 0064, 0116, 0030, 0020, 0132, 0101, 0147, 0065, 0066, 0244, 0355, 0200, 0350, 0255, 
  0217, 0303, 0115, 0052, 0374, 0063, 0166, 0312, 0062, 0353, 0217, 0337, 0326, 0335, 0050, 0130, 
  0136, 0176, 0175, 0176, 0245, 0155, 0202, 0302, 0076, 0065, 0016, 0112, 0356, 0214, 0345, 0154, 
  0376, 0345, 0330, 0107, 0046, 0277, 0166, 0076, 0166, 0345, 0327, 0013, 0342, 0022, 0201, 0031, 
  0270, 0363, 0264, 0055, 0372, 0372, 0175, 0055, 0150, 0050, 0032, 0313, 0372, 0130, 0274, 0014, 
  0274, 0215, 0017, 0146, 0105, 0165, 0366, 0146, 0331, 0174, 0161, 0213, 0240, 0276, 0061, 0166, 
  0131, 0140, 0323, 0250, 0035, 0354, 0102, 0007, 0062, 0004, 0266, 0167, 0260, 0015, 0233, 0105, 
  0056, 0022, 0174, 0344, 0247, 0004, 0243, 0144, 0102, 0233, 0263, 0101, 0337, 0365, 0163, 0154, 
  0213, 0254, 0114, 0072, 0240, 0104, 0121, 0134, 0253, 0027, 0346, 0240, 0046, 0215, 0262, 0303, 
  0142, 0331, 0375, 0252, 0357, 0274, 0337, 0341, 0221, 0101, 0312, 0036, 0351, 0023, 0045, 0255, 
  0172, 0267, 0361, 0073, 0127, 0045, 0112, 0362, 0357, 0204, 0261, 0007, 0242, 0153, 0115, 0042, 
  0332, 0144, 0054, 0027, 0204, 0126, 0155, 0142, 0332, 0246, 0317, 0273, 0302, 0043, 0262, 0104, 
  0336, 0130, 0112, 0101, 0325, 0132, 0234, 0370, 0031, 0045, 0135, 0324, 0161, 0166, 0030, 0242, 
  0171, 0353, 0220, 0023, 0065, 0244, 0027, 0164, 0171, 0006, 0132, 0253, 0246, 0313, 0123, 0044, 
  0257, 0244, 0037, 0362, 0054, 0221, 0232, 0031, 0266, 0173, 0071, 0153, 0323, 0025, 0253, 0246, 
  0335, 0336, 0234, 0105, 0216, 0335, 0306, 0214, 0322, 0066, 0025, 0202, 0365, 0234, 0142, 0226, 
  0050, 0266, 0304, 0057, 0226, 0170, 0364, 0271, 0243, 0253, 0300, 0110, 0010, 0106, 0175, 0251, 
  0252, 0023, 0361, 0312, 0116, 0066, 0007, 0161, 0347, 0147, 0033, 0355, 0147, 0206, 0343, 0133, 
  0356, 0255, 0067, 0207, 0016, 0227, 0222, 0367, 0067, 0325, 0331, 0227, 0013, 0205, 0337, 0267, 
  0315, 0303, 0163, 0025, 0020, 0305, 0013, 0211, 0173, 0064, 0165, 0331, 0057, 0145, 0370, 0346, 
  0057, 0034, 0052, 0337, 0031, 0136, 0211, 0200, 0056, 0351, 0163, 0227, 0332, 0272, 0030, 0355, 
  0022, 0031, 0213, 0205, 0101, 0100, 0317, 0143, 0215, 0125, 0373, 0365, 0033, 0270, 0224, 0301, 
  0156, 0020, 0017, 0113, 0103, 0330, 0272, 0150, 0137, 0241, 0037, 0227, 0327, 0327, 0145, 0330, 
  0114, 0312, 0260, 0171, 0113, 0007, 0077, 0336, 0071, 0170, 0170, 0160, 0323, 0326, 0013, 0337, 
  0377, 0235, 0167, 0307, 0152, 0230, 0267, 0160, 0355, 0167, 0350, 0125, 0032, 0177, 0265, 0242, 
  0104, 0323, 0003, 0207, 0235, 0163, 0151, 0347, 0272, 0011, 0101, 0371, 0262, 0111, 0256, 0061, 
  0123, 0324, 0106, 0344, 0275, 0375, 0012, 0362, 0336, 0301, 0056, 0357, 0345, 0255, 0142, 0027, 
  0164, 0377, 0176, 0066, 0167, 0042, 0261, 0167, 0145, 0347, 0026, 0227, 0235, 0257, 0024, 0053, 
  0136, 0325, 0073, 0173, 0304, 0136, 0070, 0330, 0237, 0035, 0077, 0017, 0325, 0342, 0105, 0267, 
  0301, 0052, 0322, 0320, 0223, 0117, 0300, 0111, 0300, 0024, 0114, 0023, 0122, 0031, 0044, 0253, 
  0214, 0001, 0145, 0131, 0224, 0070, 0340, 0257, 0372, 0240, 0077, 0211, 0137, 0250, 0265, 0362, 
  0242, 0071, 0002, 0217, 0020, 0165, 0035, 0175, 0161, 0220, 0213, 0274, 0174, 0252, 0167, 0373, 
  0212, 0235, 0366, 0240, 0002, 0247, 0075, 0334, 0160, 0247, 0165, 0070, 0162, 0271, 0104, 0016, 
  0365, 0345, 0100, 0164, 0052, 0164, 0334, 0163, 0127, 0377, 0001, 0147, 0034, 0334, 0162, 0011, 
  0316, 0102, 0376, 0073, 0337, 0335, 0371, 0356, 0353, 0370, 0356, 0141, 0005, 0276, 0173, 0364, 
  0137, 0372, 0156, 0032, 0202, 0351, 0350, 0045, 0135, 0073, 0050, 0163, 0044, 0235, 0357, 0346, 
  0301, 0132, 0127, 0073, 0123, 0040, 0332, 0324, 0213, 0225, 0345, 0157, 0142, 0274, 0223, 0133, 
  0145, 0131, 0362, 0146, 0337, 0017, 0133, 0224, 0161, 0241, 0261, 0021, 0206, 0107, 0053, 0054, 
  0372, 0243, 0262, 0142, 0361, 0065, 0020, 0304, 0367, 0124, 0355, 0252, 0146, 0143, 0035, 0300, 
  0326, 0364, 0113, 0052, 0125, 0216, 0304, 0073, 0145, 0223, 0176, 0236, 0221, 0036, 0031, 0111, 
  0227, 0136, 0006, 0163, 0211, 0317, 0334, 0260, 0253, 0244, 0022, 0335, 0243, 0076, 0235, 0134, 
  0072, 0065, 0214, 0116, 0055, 0147, 0037, 0226, 0116, 0157, 0144, 0104, 0123, 0324, 0237, 0262, 
  0206, 0357, 0364, 0167, 0254, 0004, 0004, 0231, 0165, 0372, 0301, 0152, 0214, 0000, 0350, 0313, 
  0174, 0115, 0330, 0265, 0173, 0052, 0163, 0010, 0201, 0047, 0363, 0072, 0160, 0205, 0105, 0360, 
  0223, 0237, 0203, 0122, 0102, 0174, 0116, 0015, 0107, 0345, 0363, 0210, 0126, 0360, 0121, 0374, 
  0152, 0037, 0147, 0201, 0170, 0173, 0306, 0324, 0337, 0346, 0036, 0270, 0126, 0025, 0130, 0300, 
  0320, 0100, 0125, 0207, 0055, 0035, 0252, 0331, 0162, 0227, 0106, 0055, 0066, 0112, 0341, 0021, 
  0037, 0164, 0002, 0311, 0030, 0122, 0254, 0364, 0051, 0077, 0346, 0151, 0220, 0054, 0262, 0004, 
  0235, 0246, 0224, 0012, 0145, 0235, 0216, 0233, 0045, 0356, 0164, 0340, 0124, 0211, 0033, 0265, 
  0231, 0216, 0347, 0106, 0335, 0250, 0305, 0076, 0305, 0376, 0027, 0322, 0101, 0311, 0275, 0000, 
  0050, 0165, 0165, 0141, 0171, 0051, 0160, 0162, 0157, 0160, 0145, 0162, 0164, 0151, 0145, 0163, 
  0057, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 0155, 0141, 0164, 0145, 0057, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[1925]; const double alignment; void * const ptr;}  notification_properties_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\310\000\000\000\000\000\000\050\006\000\000\000"
  "\000\000\000\000\001\000\000\000\002\000\000\000\003\000\000\000"
  "\004\000\000\000\005\000\000\000\212\044\233\353\005\000\000\000"
  "\310\000\000\000\016\000\114\000\330\000\000\000\334\000\000\000"
  "\113\120\220\013\002\000\000\000\334\000\000\000\004\000\114\000"
  "\340\000\000\000\344\000\000\000\324\265\002\000\377\377\377\377"
  "\344\000\000\000\001\000\114\000\350\000\000\000\354\000\000\000"
  "\247\134\140\271\004\000\000\000\354\000\000\000\037\000\166\000"
  "\020\001\000\000\146\007\000\000\006\204\047\246\000\000\000\000"
  "\146\007\000\000\013\000\114\000\164\007\000\000\170\007\000\000"
  "\201\321\040\031\001\000\000\000\170\007\000\000\005\000\114\000"
  "\200\007\000\000\204\007\000\000\156\157\164\151\146\151\143\141"
  "\164\151\157\156\163\057\000\000\004\000\000\000\157\162\147\057"
  "\005\000\000\000\057\000\000\000\001\000\000\000\155\141\164\145"
  "\055\156\157\164\151\146\151\143\141\164\151\157\156\055\160\162"
  "\157\160\145\162\164\151\145\163\056\165\151\000\000\000\000\000"
  "\276\075\000\000\001\000\000\000\170\332\355\133\133\163\342\066"
  "\024\176\337\137\241\352\141\137\072\136\102\056\335\164\027\330"
  "\111\066\331\154\046\327\111\110\137\065\302\126\100\215\260\134"
  "\131\334\072\375\361\225\154\060\006\344\053\156\002\015\057\214"
  "\261\164\216\164\276\163\323\221\344\306\267\161\237\201\041\021"
  "\076\345\156\023\326\077\355\101\100\134\233\073\324\355\066\341"
  "\123\373\207\165\014\277\265\076\064\250\053\211\170\306\066\151"
  "\175\000\240\041\310\137\003\052\210\017\030\355\064\141\127\276"
  "\374\012\347\074\366\077\325\217\141\055\350\367\213\145\201\210"
  "\322\162\161\137\161\265\074\316\250\075\001\222\173\214\014\011"
  "\263\154\256\172\214\345\000\063\140\131\001\031\357\374\111\154"
  "\011\154\206\175\277\011\057\344\313\031\305\214\167\041\240\116"
  "\023\072\341\263\356\250\272\172\202\173\104\310\011\120\314\111"
  "\023\332\330\105\317\334\036\370\260\365\003\063\237\064\152\263"
  "\016\346\376\152\002\256\124\235\057\316\256\320\375\335\345\155"
  "\373\374\001\335\334\265\057\357\156\321\315\311\343\025\370\007"
  "\030\132\176\252\177\361\346\323\247\166\133\275\276\177\070\177"
  "\174\064\274\177\070\277\076\077\171\074\017\132\262\346\323\341"
  "\302\041\002\215\250\043\173\260\165\224\325\135\122\311\010\004"
  "\122\140\327\147\130\342\016\123\057\047\104\011\164\313\045\175"
  "\246\066\226\112\045\340\221\110\251\220\367\263\330\051\215\322"
  "\277\065\223\234\350\215\250\353\360\021\362\270\117\365\070\260"
  "\145\023\255\154\213\273\226\207\205\172\316\142\100\225\356\221"
  "\176\204\255\076\226\312\102\142\263\266\246\175\051\311\234\267"
  "\234\170\004\365\224\241\301\126\150\035\053\004\166\217\062\047"
  "\064\105\027\053\223\323\177\233\160\330\341\343\251\041\231\254"
  "\356\217\123\325\034\263\071\113\367\257\107\004\253\363\030\122"
  "\237\006\350\265\305\140\005\274\062\346\152\242\361\075\154\053"
  "\145\302\326\276\261\267\131\122\154\153\110\221\122\012\216\315"
  "\337\044\364\317\323\201\224\334\135\026\075\306\240\276\300\241"
  "\004\012\145\221\060\321\061\074\341\003\211\174\071\321\043\022"
  "\327\111\044\014\220\130\174\147\222\077\024\077\224\275\023\074"
  "\037\302\145\252\222\062\147\310\135\224\124\020\233\320\041\361"
  "\221\103\236\361\200\311\014\344\114\054\006\076\101\063\315\172"
  "\036\301\052\216\330\044\017\037\043\230\146\100\117\030\355\272"
  "\175\025\014\102\114\361\354\357\076\064\321\257\001\355\072\146"
  "\225\104\077\366\155\254\307\336\053\112\070\311\115\230\010\145"
  "\222\177\316\074\263\247\242\321\001\114\242\134\023\310\052\300"
  "\054\036\275\212\201\143\006\350\262\217\273\044\104\210\352\307"
  "\175\230\106\137\001\114\125\101\125\141\202\054\302\336\122\071"
  "\137\261\077\310\307\243\121\013\001\117\355\243\164\374\242\224"
  "\134\154\056\144\354\141\327\131\023\257\147\312\330\232\054\346"
  "\253\231\275\274\220\144\312\333\250\145\030\162\031\103\277\306"
  "\035\302\102\103\147\372\261\276\325\226\316\102\151\014\113\131"
  "\164\057\310\220\222\121\131\316\072\311\015\134\265\254\146\324"
  "\055\044\354\173\262\365\372\153\331\172\072\250\051\304\311\204"
  "\011\104\111\004\311\052\053\255\246\222\252\051\025\172\022\124"
  "\140\004\241\374\242\367\050\307\242\067\164\331\226\052\377\055"
  "\233\361\142\242\276\305\202\131\223\106\153\345\155\132\155\033"
  "\370\370\222\333\057\131\122\154\263\007\324\253\360\000\023\000"
  "\146\341\113\011\156\026\272\110\331\253\347\202\364\366\105\172"
  "\355\132\064\116\030\020\132\101\147\065\066\244\355\200\350\255"
  "\217\303\115\052\374\063\166\312\062\353\217\337\326\335\050\130"
  "\136\176\175\176\245\155\202\302\076\065\016\112\356\214\345\154"
  "\376\345\330\107\046\277\166\076\166\345\327\013\342\022\201\031"
  "\270\363\264\055\372\372\175\055\150\050\032\313\372\130\274\014"
  "\274\215\017\146\105\165\366\146\331\174\161\213\240\276\061\166"
  "\131\140\323\250\035\354\102\007\062\004\266\167\260\015\233\105"
  "\056\022\174\344\247\004\243\144\102\233\263\101\337\365\163\154"
  "\213\254\114\072\240\104\121\134\253\027\346\240\046\215\262\303"
  "\142\331\375\252\357\274\337\341\221\101\312\036\351\023\045\255"
  "\172\267\361\073\127\045\112\362\357\204\261\007\242\153\115\042"
  "\332\144\054\027\204\126\155\142\332\246\317\273\302\043\262\104"
  "\336\130\112\101\325\132\234\370\031\045\135\324\161\166\030\242"
  "\171\353\220\023\065\244\027\164\171\006\132\253\246\313\123\044"
  "\257\244\037\362\054\221\232\031\266\173\071\153\323\025\253\246"
  "\335\336\234\105\216\335\306\214\322\066\025\202\365\234\142\226"
  "\050\266\304\057\226\170\364\271\243\253\300\110\010\106\175\251"
  "\252\023\361\312\116\066\007\161\347\147\033\355\147\206\343\133"
  "\356\255\067\207\016\227\222\367\067\325\331\227\013\205\337\267"
  "\315\303\163\025\020\305\013\211\173\064\165\331\057\145\370\346"
  "\057\034\052\337\031\136\211\200\056\351\163\227\332\272\030\355"
  "\022\031\213\205\101\100\317\143\215\125\373\365\033\270\224\301"
  "\156\020\017\113\103\330\272\150\137\241\037\227\327\327\145\330"
  "\114\312\260\171\113\007\077\336\071\170\170\160\323\326\013\337"
  "\377\235\167\307\152\230\267\160\355\167\350\125\032\177\265\242"
  "\104\323\003\207\235\163\151\347\272\011\101\371\262\111\256\061"
  "\123\324\106\344\275\375\012\362\336\301\056\357\345\255\142\027"
  "\164\377\176\066\167\042\261\167\145\347\026\227\235\257\024\053"
  "\136\325\073\173\304\136\070\330\237\035\077\017\325\342\105\267"
  "\301\052\322\320\223\117\300\111\300\024\114\023\122\031\044\253"
  "\214\001\145\131\224\070\340\257\372\240\077\211\137\250\265\362"
  "\242\071\002\217\020\165\035\175\161\220\213\274\174\252\167\373"
  "\212\235\366\240\002\247\075\334\160\247\165\070\162\271\104\016"
  "\365\345\100\164\052\164\334\163\127\377\001\147\034\334\162\011"
  "\316\102\376\073\337\335\371\356\353\370\356\141\005\276\173\364"
  "\137\372\156\032\202\351\350\045\135\073\050\163\044\235\357\346"
  "\301\132\127\073\123\040\332\324\213\225\345\157\142\274\223\133"
  "\145\131\362\146\337\017\133\224\161\241\261\021\206\107\053\054"
  "\372\243\262\142\361\065\020\304\367\124\355\252\146\143\035\300"
  "\326\364\113\052\125\216\304\073\145\223\176\236\221\036\031\111"
  "\227\136\006\163\211\317\334\260\253\244\022\335\243\076\235\134"
  "\072\065\214\116\055\147\037\226\116\157\144\104\123\324\237\262"
  "\206\357\364\167\254\004\004\231\165\372\301\152\214\000\350\313"
  "\174\115\330\265\173\052\163\010\201\047\363\072\160\205\105\360"
  "\223\237\203\122\102\174\116\015\107\345\363\210\126\360\121\374"
  "\152\037\147\201\170\173\306\324\337\346\036\270\126\025\130\300"
  "\320\100\125\207\055\035\252\331\162\227\106\055\066\112\341\021"
  "\037\164\002\311\030\122\254\364\051\077\346\151\220\054\262\004"
  "\235\246\224\012\145\235\216\233\045\356\164\340\124\211\033\265"
  "\231\216\347\106\335\250\305\076\305\376\027\322\101\311\275\000"
  "\050\165\165\141\171\051\160\162\157\160\145\162\164\151\145\163"
  "\057\000\000\000\003\000\000\000\155\141\164\145\057\000\000\000"
  "\000\000\000\000" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { notification_properties_resource_data.data, sizeof (notification_properties_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *notification_properties_get_resource (void);
GResource *notification_properties_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
